/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Automation, New Tasks, and Inequality, By Daron Acemoglu and Pascual Restrepo
Created 11/30/2019
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

if missing("`project'") {
	global project ~/Dropbox/RA_Pascual/Replication/Acemoglu_Restrepo_SBTC_PP
}
global bcolor "255 127 0%70"
global task_measure bea_s08_5yr
global wvar indwts
global young a25_34
global old   a35_64

*wbill_census_1990+wbill_census_2014

**************************************
***Load programs to produce figures***
**************************************
cap program drop resid_plot
program define resid_plot, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) xtitle(string) ytitle(string)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r
	tempvar est_sample
	tempvar residual_y
	tempvar projected_y
	quietly: gen `est_sample'=e(sample)
	quietly: predict `residual_y' if `est_sample'==1, resid
	quietly: sum `y_vars' if e(sample) `wt'
	quietly: gen `projected_y'=`residual_y'+r(mean)
	quietly: sum `x_var' if e(sample) `wt'
	quietly: replace `projected_y'=`projected_y'+_b[`x_var']*(`x_var'-r(mean))
	
	*Define set of markers to label*
	tempvar tag_label
	tempvar tag_rank
	quietly: gen `tag_label'=0
	quietly: replace `tag_label'=1 if 	indname=="Textiles" | ///
										indname=="Plastic and rubber products" | ///
										indname=="Primary metals" | ///
										indname=="Computers and electronics" | ///
										indname=="Retail"
	
	*Residuals*
	quietly: egen `tag_rank'=rank(`residual_y') if `residual_y'!=.
	quietly: sum `residual_y' if abs(`tag_rank'-4)<.6
	quietly: replace `tag_label'=1 if `residual_y'<r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`residual_y') if `residual_y'!=.
	quietly: sum `residual_y' if abs(`tag_rank'-4)<.6
	quietly: replace `tag_label'=1 if `residual_y'>r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Yvar*
	quietly: egen `tag_rank'=rank(`y_vars') if `residual_y'!=.
	quietly: sum `y_vars' if abs(`tag_rank'-4)<.6
	quietly: replace `tag_label'=1 if `y_vars'<r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`y_vars') if `residual_y'!=.
	quietly: sum `y_vars' if abs(`tag_rank'-4)<.6
	quietly: replace `tag_label'=1 if `y_vars'>r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Xvar*
	quietly: egen `tag_rank'=rank(`x_var') if `residual_y'!=.
	quietly: sum `x_var' if abs(`tag_rank'-2)<.6
	quietly: replace `tag_label'=1 if `x_var'<r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`x_var') if `residual_y'!=.
	quietly: sum `x_var' if abs(`tag_rank'-5)<.6
	quietly: replace `tag_label'=1 if `x_var'>r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: sum `x_var' `if', d
	local min=-0.1
	local max=r(max)
	
	twoway (scatter `projected_y' `x_var' `wt' if `projected_y'!=., mcolor("${bcolor}") msize(small) msymbol(circle) mlcolor(black) mlwidth(vthin)) ///
		   (lfit    `projected_y' `x_var' `wt' if `projected_y'!=., range(`min' `max') lcolor(gs4) lwidth(thin)) ///
		   (scatter `projected_y' `x_var' if `tag_label'==1, mcolor("${bcolor}") msize(zero) mlabel(indname) mlabsize(vsmall) mlabcolor(gs8) mlabposition(12) mlabgap(small)), ///
		   legend(off) xtitle("`xtitle'", size(medium)) ytitle("`ytitle'", size(medium)) ///
		   ysize(5) xsize(8) ylabel(, labsize(small) grid glwidth(thin) glcolor(white)) xlabel(#10, labsize(small) grid glwidth(thin) glcolor(white))  graphregion(fcolor(white) ifcolor(white)  lcolor(white) ilcolor(white)) plotregion(fcolor(white))


end

cap program drop descriptive_plot
program define descriptive_plot, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) xtitle(string) ytitle(string)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r
	tempvar est_sample
	tempvar residual_y
	tempvar projected_y
	quietly: gen `est_sample'=e(sample)
	quietly: predict `residual_y' if `est_sample'==1, resid
	quietly: sum `y_vars' if e(sample) `wt'
	quietly: gen `projected_y'=`residual_y'+r(mean)
	quietly: sum `x_var' if e(sample) `wt'
	quietly: replace `projected_y'=`projected_y'+_b[`x_var']*(`x_var'-r(mean))
	
	*Define set of markers to label*
	tempvar tag_label
	tempvar tag_rank
	quietly: gen `tag_label'=0
	quietly: replace `tag_label'=1 if 	indname=="Textiles" | ///
										indname=="Plastic and rubber products" | ///
										indname=="Primary metals" | ///
										indname=="Computers and electronics" | ///
										indname=="Retail"
									  
	*Residuals*
	quietly: egen `tag_rank'=rank(`residual_y') if `residual_y'!=.
	quietly: sum `residual_y' if abs(`tag_rank'-4)<.6
	quietly: replace `tag_label'=1 if `residual_y'<r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`residual_y') if `residual_y'!=.
	quietly: sum `residual_y' if abs(`tag_rank'-4)<.6
	quietly: replace `tag_label'=1 if `residual_y'>r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Yvar*
	quietly: egen `tag_rank'=rank(`y_vars') if `residual_y'!=.
	quietly: sum `y_vars' if abs(`tag_rank'-4)<.6
	quietly: replace `tag_label'=1 if `y_vars'<r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`y_vars') if `residual_y'!=.
	quietly: sum `y_vars' if abs(`tag_rank'-4)<.6
	quietly: replace `tag_label'=1 if `y_vars'>r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Xvar*
	quietly: egen `tag_rank'=rank(`x_var') if `residual_y'!=.
	quietly: sum `x_var' if abs(`tag_rank'-2)<.6
	quietly: replace `tag_label'=1 if `x_var'<r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`x_var') if `residual_y'!=.
	quietly: sum `x_var' if abs(`tag_rank'-5)<.6
	quietly: replace `tag_label'=1 if `x_var'>r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: sum `x_var' `if', d
	local min=r(min)-0.1
	local max=r(max)+0.1
	
	twoway (scatter `projected_y' `x_var' `wt' if `projected_y'!=., mcolor("${bcolor}") msize(small) msymbol(circle) mlcolor(black) mlwidth(vthin)) ///
		   (scatter `projected_y' `x_var' if `tag_label'==1, mcolor("${bcolor}") msize(zero) mlabel(indname) mlabsize(vsmall) mlabcolor(gs8) mlabposition(12) mlabgap(small)), ///
		   legend(off) xtitle("`xtitle'", size(medium)) ytitle("`ytitle'", size(medium)) ///
		   ysize(8) xsize(8) ylabel(0(0.2)1, labsize(small) grid glwidth(thin) glcolor(white)) xlabel(0(0.2)1, labsize(small) grid glwidth(thin) glcolor(white))  graphregion(fcolor(white) ifcolor(white)  lcolor(white) ilcolor(white)) plotregion(fcolor(white))


end


************************
****1987-2016 sample****
************************

**Create measures of SBTC**
use "${project}/clean_data/industry_sbtc_1990.dta", clear
merge 1:1 consolidated_bea using "${project}/clean_data/industry_sbtc_2014.dta", nogenerate
merge 1:1 consolidated_bea using "${project}/clean_data/industry_sbtc_klems.dta", nogenerate

local alpha=0.5
foreach var in wbill heads weeks hours {
foreach year in 1990 2014{

gen sbtch_`var'_`year'=ln((`var'_college_`year'+(`alpha')*`var'_somecollege_`year')/(`var'_highschool_`year'+(1-`alpha')*`var'_somecollege_`year'))

gen sbtch_male_`var'_`year'=ln((`var'_college_male_`year'+(`alpha')*`var'_somecollege_male_`year')/(`var'_highschool_male_`year'+(1-`alpha')*`var'_somecollege_male_`year'))
gen sbtch_female_`var'_`year'=ln((`var'_college_female_`year'+(`alpha')*`var'_somecollege_female_`year')/(`var'_highschool_female_`year'+(1-`alpha')*`var'_somecollege_female_`year'))

gen sbtch_pmale_`var'_`year'=ln((`var'_college_pmale_`year'+(`alpha')*`var'_somecollege_pmale_`year')/(`var'_highschool_pmale_`year'+(1-`alpha')*`var'_somecollege_pmale_`year'))
gen sbtch_pfemale_`var'_`year'=ln((`var'_college_pfemale_`year'+(`alpha')*`var'_somecollege_pfemale_`year')/(`var'_highschool_pfemale_`year'+(1-`alpha')*`var'_somecollege_pfemale_`year'))

gen sbtch_young_`var'_`year'=ln((`var'_college_${young}_`year'+(`alpha')*`var'_somecollege_${young}_`year')/(`var'_highschool_${young}_`year'+(1-`alpha')*`var'_somecollege_${young}_`year'))
gen sbtch_old_`var'_`year'=ln((`var'_college_${old}_`year'+(`alpha')*`var'_somecollege_${old}_`year')/(`var'_highschool_${old}_`year'+(1-`alpha')*`var'_somecollege_${old}_`year'))
gen sbtch_prime_`var'_`year'=ln((`var'_college_a25_54_`year'+(`alpha')*`var'_somecollege_a25_54_`year')/(`var'_highschool_a25_54_`year'+(1-`alpha')*`var'_somecollege_a25_54_`year'))

assert abs(`var'_college_`year'-`var'_college_male_`year'-`var'_college_female_`year')<0.1 if `var'_college_`year'!=.
assert abs(`var'_somecollege_`year'-`var'_somecollege_male_`year'-`var'_somecollege_female_`year')<0.1 if `var'_college_`year'!=.
assert abs(`var'_highschool_`year'-`var'_highschool_male_`year'-`var'_highschool_female_`year')<0.1 if `var'_college_`year'!=.


gen `var'_census_`year'=wbill_college_`year'+wbill_somecollege_`year'+wbill_college_`year'

}
gen change_sbtch_`var'=sbtch_`var'_2014-sbtch_`var'_1990
gen change_male_sbtch_`var'=sbtch_male_`var'_2014-sbtch_male_`var'_1990
gen change_female_sbtch_`var'=sbtch_female_`var'_2014-sbtch_female_`var'_1990

gen change_pmale_sbtch_`var'=sbtch_pmale_`var'_2014-sbtch_pmale_`var'_1990
gen change_pfemale_sbtch_`var'=sbtch_pfemale_`var'_2014-sbtch_pfemale_`var'_1990

gen change_young_sbtch_`var'=sbtch_young_`var'_2014-sbtch_young_`var'_1990
gen change_old_sbtch_`var'=sbtch_old_`var'_2014-sbtch_old_`var'_1990
gen change_prime_sbtch_`var'=sbtch_prime_`var'_2014-sbtch_prime_`var'_1990

}

*measure from klems*
gen change_sbtch_klems=ln(labor_c_2016/labor_n_2016)-ln(labor_c_1987/labor_n_1987) 
gen wbill_klems_1987=labor_c_1987+labor_n_1987

keep consolidated_bea change_* sbtch_* employment* wbill_klems_1987 wbill_census*

**Measures of changes in task content**
merge 1:1 consolidated_bea using "${project}/clean_data/task_content_bea_1987_2017_0.8.dta", nogenerate
merge 1:1 consolidated_bea using "${project}/clean_data/task_content_klems_1987_2017_0.8.dta", nogenerate


gen task_content_bea_s08=task_content_i
gen gross_change_bea_s08_5yr=task_positive_5yr-task_negative_5yr
gen automation_bea_s08_5yr=-task_negative_5yr
gen reinstatement_bea_s08_5yr=task_positive_5yr

gen gross_change_bea_s08_10yr=task_positive_10yr-task_negative_10yr
gen automation_bea_s08_10yr=-task_negative_10yr
gen reinstatement_bea_s08_10yr=task_positive_10yr

gen task_content_klems_s08=task_content_i_klems
gen gross_change_klems_s08_5yr=task_positive_5yr_klems-task_negative_5yr_klems
gen automation_klems_s08_5yr=-task_negative_5yr_klems
gen reinstatement_klems_s08_5yr=task_positive_5yr_klems

gen gross_change_klems_s08_10yr=task_positive_10yr_klems-task_negative_10yr_klems
gen automation_klems_s08_10yr=-task_negative_10yr_klems
gen reinstatement_klems_s08_10yr=task_positive_10yr_klems

drop task_content_i task_content_i_klems  ///
     task_positive_5yr task_negative_5yr  task_positive_5yr_klems task_negative_5yr_klems ///
	 task_positive_10yr task_negative_10yr task_positive_10yr_klems task_negative_10yr_klems

merge 1:1 consolidated_bea using "${project}/clean_data/task_content_bea_1987_2017_1.0.dta", nogenerate
merge 1:1 consolidated_bea using "${project}/clean_data/task_content_klems_1987_2017_1.0.dta", nogenerate

gen task_content_bea_s1=task_content_i
gen gross_change_bea_s1_5yr=task_positive_5yr-task_negative_5yr
gen automation_bea_s1_5yr=-task_negative_5yr
gen reinstatement_bea_s1_5yr=task_positive_5yr

gen gross_change_bea_s1_10yr=task_positive_10yr-task_negative_10yr
gen automation_bea_s1_10yr=-task_negative_10yr
gen reinstatement_bea_s1_10yr=task_positive_10yr

gen task_content_klems_s1=task_content_i_klems
gen gross_change_klems_s1_5yr=task_positive_5yr_klems-task_negative_5yr_klems
gen automation_klems_s1_5yr=-task_negative_5yr_klems
gen reinstatement_klems_s1_5yr=task_positive_5yr_klems

gen gross_change_klems_s1_10yr=task_positive_10yr_klems-task_negative_10yr_klems
gen automation_klems_s1_10yr=-task_negative_10yr_klems
gen reinstatement_klems_s1_10yr=task_positive_10yr_klems

drop task_content_i task_content_i_klems  ///
     task_positive_5yr task_negative_5yr task_positive_5yr_klems task_negative_5yr_klems ///
	 task_positive_10yr task_negative_10yr  task_positive_10yr_klems task_negative_10yr_klems	
	 
*Special groups of industries and industriy names*
gen indname=consolidated_bea
encode indname, gen (indcode)

gen extractive=( consolidated_bea=="Mining" ///
               | consolidated_bea=="Oil and gas extraction" ///
			   | consolidated_bea=="Petroleum and coal products" ///
			   | consolidated_bea=="Agriculture and farming")
	   
****PART 1: DESCRIPTIVE STATISTICS****

egen totwts=total(${wvar}*(1-extractive))
replace ${wvar}=${wvar}/totwts

*Descriptive: reinstatement vs displacement
cor automation_${task_measure} reinstatement_${task_measure} [w=${wvar}]
cor automation_${task_measure} reinstatement_${task_measure} [w=${wvar}] if extractive==0
cor automation_${task_measure} reinstatement_${task_measure} [w=${wvar}] if gross_change_${task_measure}<1
			

sum reinstatement_${task_measure} automation_${task_measure} [w=${wvar}]  if extractive==0

****PART 2: FIGURES FOR AUTOMATION AND REINSTATEMENT****

**Figure 1b: Automation**
resid_plot change_sbtch_wbill automation_${task_measure} [w=${wvar}] if extractive==0, xtitle("b. Displacement, 1987-2016") ytitle(Change in log college wage bill relative to high school)
graph export ${project}/figures/figure1b.png, as(png) width(3000) replace


** Figure 1d: Reinstatement**
resid_plot change_sbtch_wbill reinstatement_${task_measure} [w=${wvar}] if extractive==0, xtitle("d. Reinstatement 1987-2016") ytitle(Change in log college wage bill relative to high school)
graph export ${project}/figures/figure1d.png, as(png) width(3000) replace

* Figure A.1b		
descriptive_plot reinstatement_${task_measure} automation_${task_measure} [w=${wvar}] if extractive==0, xtitle("b. Displacement, 1987-2016") ytitle(Reinstatement 1987-2016)
graph export ${project}/figures/figureA1b.png, as(png) replace


****PART 3: MAIN REGRESSION TABLES ****
* Table A.2: Panel D - F

foreach var in wbill hours  heads { 

reg change_sbtch_`var' automation_${task_measure} [w=${wvar}] if extractive==0, r
estimates store e1

reg change_sbtch_`var' reinstatement_${task_measure} [w=${wvar}] if extractive==0, r
estimates store e2

reg change_sbtch_`var' automation_${task_measure} reinstatement_${task_measure} [w=${wvar}] if extractive==0, r
estimates store e3

reg change_male_sbtch_`var' automation_${task_measure} reinstatement_${task_measure} [w=${wvar}] if extractive==0, r
estimates store e4

reg change_female_sbtch_`var' automation_${task_measure} reinstatement_${task_measure} [w=${wvar}] if extractive==0, r
estimates store e5

reg change_young_sbtch_`var' automation_${task_measure} reinstatement_${task_measure} [w=${wvar}] if extractive==0, r
estimates store e6

reg change_old_sbtch_`var' automation_${task_measure} reinstatement_${task_measure} [w=${wvar}] if extractive==0, r
estimates store e7

*Export tables*
estout  e1 e2 e3 e4 e5 e6 e7 using "${project}/tables/table_main_8717_${task_measure}_`var'.tex", style(tex) ///
varlabels(automation_${task_measure} "Automation" reinstatement_${task_measure} "Reinstatement") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(automation_${task_measure} reinstatement_${task_measure}) ///
order(automation_${task_measure} reinstatement_${task_measure}) 

}

****PART 4: REGRESSION TABLES FOR ROBUSTNESS CHECKS ****
* Table A.4

foreach taskmes in bea_s08_10yr bea_s1_5yr bea_s1_10yr klems_s08_5yr klems_s1_5yr klems_s1_10yr{

reg change_sbtch_wbill automation_`taskmes' [w=${wvar}] if extractive==0, r
estimates store e1

reg change_sbtch_wbill reinstatement_`taskmes' [w=${wvar}] if extractive==0, r
estimates store e2

reg change_sbtch_wbill automation_`taskmes' reinstatement_`taskmes' [w=${wvar}] if extractive==0, r
estimates store e3

reg change_sbtch_hours automation_`taskmes' [w=${wvar}] if extractive==0, r
estimates store e4

reg change_sbtch_hours reinstatement_`taskmes' [w=${wvar}] if extractive==0, r
estimates store e5

reg change_sbtch_hours automation_`taskmes' reinstatement_`taskmes' [w=${wvar}] if extractive==0, r
estimates store e6


*Export tables*
estout  e1 e2 e3 e4 e5 e6 using "${project}/tables/table_robustness_8717_`taskmes'.tex", style(tex) ///
varlabels(automation_`taskmes' "Automation" reinstatement_`taskmes' "Reinstatement") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(automation_`taskmes' reinstatement_`taskmes') ///
order(automation_`taskmes' reinstatement_`taskmes') 

}

