/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Automation, New Tasks, and Inequality, By Daron Acemoglu and Pascual Restrepo
Created 11/30/2019
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

if missing("`project'") {
	global project ~/Dropbox/RA_Pascual/Replication/Acemoglu_Restrepo_SBTC_PP
}

global growth_rate_1987_2017 0.0146
global growth_rate_1947_1987 0.02

forvalues sigma = 0.8(0.2)1.0 {

* locals to store results *
local sigma1 = `sigma' - mod(`sigma',1)
local sigma2 = mod(`sigma'*10,10)

**KLEMS version**
use "${project}/xwalks/industry_xwalk_census_bea.dta", clear
keep if industry_bea_klems!=""
unique industry_bea_klems
keep consolidated_bea industry_bea_klems
replace industry_bea_klems=ltrim(rtrim(industry_bea_klems))
tempfile klems_data
save `klems_data', replace

	*extract BEA-KLEMS data*
foreach var in vadded revenue labor_n labor_c vadded_qty labor_qty tfp labor_prod {

if "`var'"=="vadded"{
local tabname "Value Added"
}
if "`var'"=="revenue"{
local tabname "Gross Output"
}
else if "`var'"=="labor_n"{
local tabname "Labor_NoCol Compensation"
}
else if "`var'"=="labor_c"{
local tabname "Labor_Col Compensation"
}
else if "`var'"=="vadded_qty"{
local tabname "VA_Quantity"
}
else if "`var'"=="labor_qty"{
local tabname "Labor Input_Quantity"
}
else if "`var'"=="materials"{
local tabname "Materials Compensation"
}
else if "`var'"=="output"{
local tabname "Gross Output"
}
else if "`var'"=="tfp"{
local tabname "Integrated MFP Index"
}
else if "`var'"=="labor_prod"{
local tabname "Integrated Labor Productivity"
}
	**KLEMS data for 1998-2016**
import excel "${project}/raw_data/BEA-BLS-industry-level-production-account-1998-2016.xlsx", ///
             sheet("`tabname'") cellrange(A2:T65) firstrow clear

drop if IndustryDescription ==""	 

rename IndustryDescription industry_bea_klems
			 
rename (B C D E F G H I J K L M N O P Q R S T) ///
       (`var'_1998 `var'_1999 `var'_2000 `var'_2001 `var'_2002 `var'_2003 `var'_2004 `var'_2005 `var'_2006 `var'_2007 `var'_2008 `var'_2009 `var'_2010 `var'_2011 `var'_2012 `var'_2013 `var'_2014 `var'_2015 `var'_2016)

*Normalize indices to 1998
if "`var'"=="vadded_qty" | "`var'"=="labor_qty" | "`var'"=="tfp" | "`var'"=="labor_prod"{
gen base=`var'_1998 
forvalues j=1998(1)2016{
replace `var'_`j'=`var'_`j'/base
}
}	   
	   
tempfile post_klems
save `post_klems', replace	   
	   
	**KLEMS data for 1987-1998**
import excel "${project}/raw_data/BEA-BLS-industry-level-production-account-1987-1998.xlsx", ///
             sheet("`tabname'") cellrange(A2:M65) firstrow clear

drop if IndustryDescription ==""	 

rename IndustryDescription industry_bea_klems
			 
rename (B C D E F G H I J K L M) ///
       (`var'_1987 `var'_1988 `var'_1989 `var'_1990 `var'_1991 `var'_1992 `var'_1993 `var'_1994 `var'_1995 `var'_1996 `var'_1997 `var'_1998a)

*Normalize indices to 1998
if "`var'"=="vadded_qty" | "`var'"=="labor_qty" | "`var'"=="tfp" | "`var'"=="labor_prod" {
gen base=`var'_1998a 
forvalues j=1987(1)1997{
replace `var'_`j'=`var'_`j'/base
}
replace `var'_1998a=`var'_1998a/base
}	   
	   
	   
	*merge post 98 data*
merge 1:1 industry_bea_klems using `post_klems', assert(3) nogenerate

assert `var'_1998a==`var'_1998
drop `var'_1998a

	*merge other variables*
merge 1:1 industry_bea_klems using `klems_data', assert(1 3) keep(3) nogenerate
save `klems_data', replace

}

*extract measures of SBTC*
preserve
collapse (sum) labor_n_1987 labor_c_1987 labor_n_2016 labor_c_2016, by(consolidated_bea)
save "${project}/clean_data/industry_sbtc_klems.dta", replace
restore

*extract measures of task content*
reshape long vadded_ revenue_ labor_n_ labor_c_ vadded_qty_ labor_qty_ tfp_ labor_prod_ , i(industry_bea_klems) j(year)

*aggregate indices*
preserve
encode industry_bea_klems, gen(indcode)
sort indcode year
xtset indcode year
gen log_index=ln(vadded_qty_)
gen change_y=d.log_index
gen weights_y=(vadded_+l.vadded_)/2
collapse (mean) change_y [w=weights_y], by(consolidated_bea year)
tempfile change_y
save `change_y'
restore

preserve
encode industry_bea_klems, gen(indcode)
sort indcode year
xtset indcode year
gen log_index=ln(labor_qty_)
gen change_ell=d.log_index
gen weights_ell=(labor_n_+labor_c_+l.labor_n_+l.labor_c_)/2
collapse (mean) change_ell [w=weights_ell], by(consolidated_bea year)
tempfile change_ell
save `change_ell'
restore

preserve
encode industry_bea_klems, gen(indcode)
sort indcode year
xtset indcode year
gen log_index=ln(tfp_)
gen change_tfp=d.log_index
gen weights_tfp=(revenue_+l.revenue_)/2
collapse (mean) change_tfp [w=weights_tfp], by(consolidated_bea year)
tempfile change_tfp
save `change_tfp'
restore

preserve
encode industry_bea_klems, gen(indcode)
sort indcode year
xtset indcode year
gen log_index=ln(labor_prod_)
gen change_labprod=d.log_index
gen weights_labprod=(labor_n_+labor_c_+l.labor_n_+l.labor_c_)/2
collapse (mean) change_labprod [w=weights_labprod], by(consolidated_bea year)
tempfile change_labprod
save `change_labprod'
restore

	*aggregate data to categories*
	*that can be consistently mapped to census*
collapse (sum) vadded_ labor_n_ labor_c_, by(consolidated_bea year)
merge 1:1 consolidated_bea year using `change_y', nogenerate
merge 1:1 consolidated_bea year using `change_ell', nogenerate
merge 1:1 consolidated_bea year using `change_tfp', nogenerate
merge 1:1 consolidated_bea year using `change_labprod', nogenerate

encode consolidated_bea, gen(indcode)
sort indcode year
gen vadded_i=vadded_
gen wages_i=labor_n_+labor_c_

* * * Sectoral shares and statistics                                    * * * * 
* * * Share of GDP, Labor share at time t and at intitial point (1987)  * * * *

bys year: egen wbill_us=total(wages_i)					/*Wage bill in nominal terms*/

* * * Measure the contribution of changes in TASK CONTENT of production  		* * * *
* * *  and SUBSTITUTION effects (see the appendix for derivations, pagg. A8-A10) * * * *
sort indcode year

gen labsh_i=wages_i/vadded_i 				/*Labor share i: Contribution of labor to value added in sector i (s_i)*/

bys indcode: gen base_labsh=labsh_i[1]		/*Initial labor share in industry i (s_i in 1987) */
assert base_labsh==labsh_i if year==1947

gen ln_labsh_i=ln(labsh_i)  /*Observed decline in labor share, BEA */

gen task_content_i_klems=${sigma}*d.ln_labsh_i+(1-${sigma})*${growth_rate_1947_1987}+(1-${sigma})*(change_ell-change_y)   /*Formula for changes in the task content in terms of quantities*/

* * * Disentangle the DISPLACEMENT and REINSTATEMENT effect using 5 year moving averages * * *
sort indcode year

* Calculate mean of task content for each industry at 5 years MA centered at current year
* (Baseline: 5-year moving averages) 
rangestat (mean) task_content_i_klems, interval(year -2 2) by(indcode)

*Industry element of the Displacement effect:
gen task_negative_5yr_klems=min(task_content_i_klems_mean,0) 

*Industry element of the Reinstatement effect: 
gen task_positive_5yr_klems=max(task_content_i_klems_mean,0)

* Calculate mean of task content for each industry at 11 years MA centered at current year
* (Baseline: 5-year moving averages) 
drop task_content_i_klems_mean
rangestat (mean) task_content_i_klems, interval(year -5 5) by(indcode)

*Industry element of the Displacement effect:
gen task_negative_10yr_klems=min(task_content_i_klems_mean,0) 

*Industry element of the Reinstatement effect: 
gen task_positive_10yr_klems=max(task_content_i_klems_mean,0) 
 
gen indwts_klems=wages_i/wbill_us /*Use share of wage bill as weights for industry analysis (l_i)*/

*Productivity measures*
gen change_tfp_07=change_tfp if year<=2007

gcollapse (sum) task_negative_*yr_klems task_positive_*yr_klems task_content_i_klems (mean) change_tfp* change_labprod indwts_klems, by(consolidated_bea)

save ${project}/clean_data/task_content_klems_1987_2017_`sigma1'.`sigma2'.dta, replace

}

